import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
from functools import lru_cache
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')
import mns_common.utils.date_handle_util as date_handle_util


# 查询日期str_day 大于chg的数据
@lru_cache(maxsize=None)
def get_last_trade_k_line_high_chg(str_day, chg):
    query = {'date': date_handle_util.no_slash_date(str_day), "chg": {"$gte": chg}}
    return mongodb_util.find_query_data_choose_field('stock_qfq_daily', query,
                                                     query_field={'symbol': 1, 'name': 1, "chg": 1})


# 计算k线相关参数 当前最大涨幅  回落的幅度 超平均价幅度
def calculate_real_time_k_line_param(real_time_quotes_now):
    # 最大涨幅
    real_time_quotes_now['max_chg'] = round(
        (((real_time_quotes_now['high'] - real_time_quotes_now['yesterday_price']) / real_time_quotes_now[
            'yesterday_price']) * 100), 2)
    # 最大涨幅与当前涨幅的差值 越大表明是拉高出货
    real_time_quotes_now['chg_fall_back'] = round(real_time_quotes_now['max_chg'] - real_time_quotes_now['chg'], 2)
    # 当前价格与今天开盘价格的差值 为负表明为下跌趋势
    real_time_quotes_now['chg_from_open'] = round(
        (((real_time_quotes_now['now_price'] - real_time_quotes_now['open']) / real_time_quotes_now[
            'open']) * 100), 2)

    if 'average_price' in real_time_quotes_now.columns:
        # 高于平均线的差值 越大表明极速拉伸
        real_time_quotes_now['diff_avg_chg'] = round(
            (((real_time_quotes_now['now_price'] - real_time_quotes_now['average_price']) / real_time_quotes_now[
                'average_price']) * 100), 2)
    else:
        real_time_quotes_now['diff_avg_chg'] = 0
    return real_time_quotes_now


# 计算当前 成交量变化和均线数据
def calculate_exchange_and_avg_chg(real_time_quotes_now_kc):
    real_time_quotes_now_kc['exchange_chg_percent_yesterday'] = round(
        (real_time_quotes_now_kc['exchange'] / real_time_quotes_now_kc['exchange_mean_last']), 2)

    real_time_quotes_now_kc['exchange_chg_percent_ten'] = round(
        (real_time_quotes_now_kc['amount_level'] / real_time_quotes_now_kc['mean_amount_ten']), 2)

    real_time_quotes_now_kc['now_chg_diff_five'] = real_time_quotes_now_kc['close_difference_five_last'] + \
                                                   real_time_quotes_now_kc['chg']

    real_time_quotes_now_kc['now_chg_diff_ten'] = real_time_quotes_now_kc['close_difference_ten_last'] + \
                                                  real_time_quotes_now_kc['chg']

    real_time_quotes_now_kc['now_chg_diff_twenty'] = real_time_quotes_now_kc['close_difference_twenty_last'] + \
                                                     real_time_quotes_now_kc['chg']

    real_time_quotes_now_kc['now_chg_diff_thirty'] = real_time_quotes_now_kc['close_difference_thirty_last'] + \
                                                     real_time_quotes_now_kc['chg']

    real_time_quotes_now_kc['now_chg_diff_sixty'] = real_time_quotes_now_kc['close_difference_sixty_last'] + \
                                                    real_time_quotes_now_kc['chg']

    real_time_quotes_now_kc['now_chg_plus_last_chg'] = real_time_quotes_now_kc['chg_last'] + \
                                                       real_time_quotes_now_kc['chg']
    real_time_quotes_now_kc['now_chg_plus_two_days'] = (real_time_quotes_now_kc['daily01'] + \
                                                        real_time_quotes_now_kc['chg'] +
                                                        real_time_quotes_now_kc['daily02'])

    real_time_quotes_now_kc['now_chg_plus_three_days'] = real_time_quotes_now_kc['daily01'] + real_time_quotes_now_kc[
        'daily02'] + real_time_quotes_now_kc['daily03'] + real_time_quotes_now_kc['chg']

    real_time_quotes_now_kc['now_chg_plus_four_days'] = real_time_quotes_now_kc['daily01'] + real_time_quotes_now_kc[
        'daily02'] + real_time_quotes_now_kc['daily03'] + real_time_quotes_now_kc['daily04'] + real_time_quotes_now_kc[
                                                            'chg']

    return real_time_quotes_now_kc


# 获取交易日期
def get_deal_days(str_day, symbol):
    # 当天没有k线数据时 进行同步
    query = {"symbol": symbol, 'date': {"$lt": date_handle_util.no_slash_date(str_day)}}
    return mongodb_util.count(query, 'stock_qfq_daily')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.component.classify.symbol_classify_param import stock_type_classify_param


# 深沪普通股票  选择 10cm涨幅的
def choose_sh_symbol(realtime_quotes_now):
    return realtime_quotes_now.loc[
        (realtime_quotes_now['classification'].isin(['S', 'H']))]


# 选择科创 创业板 20厘米的
def choose_kc_symbol(realtime_quotes_now):
    return realtime_quotes_now.loc[
        realtime_quotes_now['classification'].isin(['K', 'C'])]


# 选择北交所的 30厘米的
def choose_bjs_symbol(realtime_quotes_now):
    return realtime_quotes_now.loc[
        realtime_quotes_now['classification'].isin(['X'])]


# 设置新股次新标记 通过交易时间
def set_stock_type_by_deal_days(real_time_quotes_now_init):
    if data_frame_util.is_empty(real_time_quotes_now_init):
        return None
    real_time_quotes_now = real_time_quotes_now_init.copy()
    real_time_quotes_now.loc[:, "stock_type"] = stock_type_classify_param['normal_stock']
    # 交易天数五个交易日的股票
    real_time_quotes_now.loc[(real_time_quotes_now['name'].str.startswith('C'))
                             | (real_time_quotes_now['deal_days'] <= stock_type_classify_param[
        'sub_stock_new_min_deal_days']), "stock_type"] = stock_type_classify_param['new_stock']

    # 交易上市6-100天的次新股票
    real_time_quotes_now.loc[
        (real_time_quotes_now['stock_type'] != stock_type_classify_param['new_stock'])
        & (real_time_quotes_now['deal_days'] > stock_type_classify_param['sub_stock_new_min_deal_days'])
        & (real_time_quotes_now['deal_days'] <= stock_type_classify_param['sub_new_stock_max_deal_days']),
        "stock_type"] = stock_type_classify_param['sub_stock_new']

    # 上市次新股 100-365
    real_time_quotes_now.loc[
        (real_time_quotes_now['deal_days'] > stock_type_classify_param['sub_new_stock_max_deal_days'])
        & (real_time_quotes_now['deal_days'] <= stock_type_classify_param['sub_stock_max_deal_days']),
        "stock_type"] = stock_type_classify_param['sub_stock']

    # 交易天数 366-730
    real_time_quotes_now.loc[
        (real_time_quotes_now['deal_days'] > stock_type_classify_param['sub_stock_max_deal_days'])
        & (real_time_quotes_now['deal_days'] <= stock_type_classify_param['normal_stock_max_deal_days']),
        "stock_type"] = stock_type_classify_param['normal_sub_stock']

    return real_time_quotes_now


# 设置新股次新标记 通过上市时间
def set_stock_type_by_diff_days(real_time_quotes_now_init):
    if data_frame_util.is_empty(real_time_quotes_now_init):
        return None
    real_time_quotes_now = real_time_quotes_now_init.copy()
    real_time_quotes_now.loc[:, "stock_type"] = stock_type_classify_param['normal_stock']
    # 上市五个交易日的股票
    real_time_quotes_now.loc[(real_time_quotes_now['name'].str.startswith('C')) | (
            real_time_quotes_now['diff_days'] < stock_type_classify_param[
        'sub_stock_new_min_diff_days']), "stock_type"] = \
        stock_type_classify_param[
            'new_stock']
    # 交易上市7-150天的次新股票
    real_time_quotes_now.loc[
        (real_time_quotes_now['stock_type'] != stock_type_classify_param['new_stock'])
        & (real_time_quotes_now['diff_days'] <= stock_type_classify_param['sub_stock_new_max_diff_days']),
        "stock_type"] = stock_type_classify_param['sub_stock_new']

    # 上市次新股 150-465
    real_time_quotes_now.loc[
        (real_time_quotes_now['diff_days'] > stock_type_classify_param['sub_stock_new_max_diff_days'])
        & (real_time_quotes_now['diff_days'] <= stock_type_classify_param['sub_stock_max_diff_days']),
        "stock_type"] = stock_type_classify_param['sub_stock']

    # 上市天数 465-930
    real_time_quotes_now.loc[
        (real_time_quotes_now['diff_days'] > stock_type_classify_param['sub_stock_max_diff_days'])
        & (real_time_quotes_now['diff_days'] <= stock_type_classify_param['normal_sub_stock_max_diff_days']),
        "stock_type"] = stock_type_classify_param['normal_sub_stock']

    return real_time_quotes_now


# 新上市注册股票 交易天数1-5天
def choose_new_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['new_stock']]

    return real_time_quotes_now


# 排除新股
def exclude_new_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['new_stock']]
    return real_time_quotes_now


# 选择次新new     # 交易上市6-100天的次新股票
def choose_sub_new(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['sub_stock_new']]

    return real_time_quotes_now


# 排除次新new      # 交易上市6-100天的次新股票
def exclude_sub_new(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['sub_stock_new']]
    return real_time_quotes_now


# 选择次新 # 交易上市100-365天的次新股票
def choose_sub_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['sub_stock']]

    return real_time_quotes_now


# 排除次新  交易上市100-365天的次新股票
def exclude_sub_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['sub_stock']]
    return real_time_quotes_now


# 选择普通sub 交易日 365-730 的股票
def choose_normal_sub_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['normal_sub_stock']]

    return real_time_quotes_now


# 排除普通sub 交易日 365-730 的股票
def exclude_normal_sub_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['normal_sub_stock']]
    return real_time_quotes_now


# 选择普通 交易日 731 到无穷天的股票
def choose_normal_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['normal_stock']]

    return real_time_quotes_now


# 排除普通 交易日 731 到无穷天的股票
def exclude_normal_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['normal_stock']]
    return real_time_quotes_now


# 根据类型列表选择
def choose_stock_by_type_list(real_time_quotes_now, type_list):
    return real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'].isin(type_list)]


# 增加市场后缀
def add_symbol_suffix(stock='600031.SH'):
    '''
    调整代码
    '''
    if (stock[-2:] == 'SH'
            or stock[-2:] == 'SZ'
            or stock[-2:] == 'sh'
            or stock[-2:] == 'sz'
            or stock[-2:] == 'BJ'
            or stock[-2:] == 'bj'):
        stock = stock.upper()
    else:
        if stock[:3] in ['600', '601', '603', '688', '510', '511',
                         '512', '513', '515', '113', '110', '118', '501'] or stock[:2] in ['11']:
            stock = stock + '.SH'
        elif stock.startswith('8') or stock.startswith('4') or stock.startswith('9'):
            stock = stock + '.BJ'
        else:
            stock = stock + '.SZ'
    return stock



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import akshare as ak
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.utils.date_handle_util as date_handle_util


def stock_zb_pool_df(date):
    try:
        date = date_handle_util.no_slash_date(date)
        stock_zb_pool = ak.stock_zt_pool_zbgc_em(date)
        if data_frame_util.is_empty(stock_zb_pool):
            return None
        stock_zb_pool.rename(columns={"序号": "index",
                                      "代码": "symbol",
                                      "名称": "name",
                                      "涨跌幅": "chg",
                                      "最新价": "now_price",
                                      "炸板股价": "zt_price",
                                      "成交额": "amount",
                                      "流通市值": "flow_mv",
                                      "总市值": "total_mv",
                                      "动态市盈率": "ttm_pe",
                                      "换手率": "exchange",
                                      "涨速": "speed",
                                      "首次封板时间": "first_closure_time",
                                      "炸板次数": "frying_plates_numbers",
                                      "炸板股统计": "statistics",
                                      "振幅": "pct_chg",
                                      "所属行业": "industry"
                                      }, inplace=True)
        stock_zb_pool.loc[stock_zb_pool['amount'] == '-', 'amount'] = 0
        stock_zb_pool.loc[stock_zb_pool['exchange'] == '-', 'exchange'] = 0
        return stock_zb_pool
    except BaseException as e:
        logger.error("同步股票炸板数据出现异常:{},{}", date, e)
        return None


if __name__ == '__main__':
    df = stock_zb_pool_df('2024-09-04')
    print(df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import requests
import json
import pandas as pd
from concurrent.futures import ThreadPoolExecutor
import datetime
from loguru import logger

# 最大返回条数
max_number = 5700
# 最小返回条数
min_number = 5600
# 分页条数
page_number = 200


def get_stock_page_data(pn, fields, fs):
    """
    获取单页股票数据
    """
    # 获取当前日期和时间
    current_time = datetime.datetime.now()

    # 将当前时间转换为时间戳（以毫秒为单位）
    current_timestamp_ms = int(current_time.timestamp() * 1000)

    url = "https://13.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
        "pn": str(pn),
        "pz": "10000",  # 每页最大200条
        "po": "1",
        "np": "3",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f3",
        "fs": fs,
        "fields": fields,
        "_": current_timestamp_ms
    }
    try:
        r = requests.get(url, params)
        data_text = r.text
        begin_index = data_text.index('[')
        end_index = data_text.index(']')
        data_json = data_text[begin_index:end_index + 1]
        data_json = json.loads(data_json)
        if data_json is None:
            return pd.DataFrame()
        else:
            return pd.DataFrame(data_json)
    except Exception as e:
        logger.error(f"获取第{pn}页股票列表异常: {e}")
        return pd.DataFrame()


def all_stock_ticker_data_new(fields, fs) -> pd.DataFrame:
    """
    使用多线程获取所有股票数据
    """

    per_page = page_number
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整

    # 创建线程池
    with ThreadPoolExecutor(max_workers=10) as executor:
        # 提交任务，获取每页数据
        futures = [executor.submit(get_stock_page_data, pn, fields, fs)
                   for pn in range(1, total_pages + 1)]

        # 收集结果
        results = []
        for future in futures:
            result = future.result()
            if not result.empty:
                results.append(result)

    # 合并所有页面的数据
    if results:
        return pd.concat(results, ignore_index=True)
    else:
        return pd.DataFrame()


def get_real_time_quotes_all_stocks():
    fields = "f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,f18,f20,f21,f26,f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212",
    fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"
    # 获取第一页数据
    page_one_df = get_stock_page_data(1, fields, fs)
    # 数据接口正常返回5600以上的数量
    if page_one_df.shape[0] > min_number:
        page_one_df = rename_real_time_quotes_df(page_one_df)
        return page_one_df
    else:
        page_df = all_stock_ticker_data_new(fields, fs)
        page_df = rename_real_time_quotes_df(page_df)
        return page_df


# 获取所有股票实时行情数据    f33,委比
def rename_real_time_quotes_df(temp_df):
    temp_df = temp_df.rename(columns={
        "f2": "now_price",
        "f3": "chg",
        "f5": "volume",
        "f6": "amount",
        "f8": "exchange",
        "f10": "quantity_ratio",
        "f22": "up_speed",
        "f11": "up_speed_05",
        "f12": "symbol",
        "f14": "name",
        "f15": "high",
        "f16": "low",
        "f17": "open",
        "f18": "yesterday_price",
        "f20": "total_mv",
        "f21": "flow_mv",
        "f26": "list_date",
        "f33": "wei_bi",
        "f34": "outer_disk",
        "f35": "inner_disk",
        "f62": "today_main_net_inflow",
        "f66": "super_large_order_net_inflow",
        "f69": "super_large_order_net_inflow_ratio",
        "f72": "large_order_net_inflow",
        # "f78": "medium_order_net_inflow",
        # "f84": "small_order_net_inflow",
        "f100": "industry",
        # "f103": "concept",
        "f184": "today_main_net_inflow_ratio",
        "f352": "average_price",
        "f211": "buy_1_num",
        "f212": "sell_1_num"
    })

    temp_df.loc[temp_df['buy_1_num'] == '-', 'buy_1_num'] = 0
    temp_df.loc[temp_df['sell_1_num'] == '-', 'sell_1_num'] = 0
    temp_df.loc[temp_df['up_speed_05'] == '-', 'up_speed_05'] = 0
    temp_df.loc[temp_df['up_speed'] == '-', 'up_speed'] = 0
    temp_df.loc[temp_df['average_price'] == '-', 'average_price'] = 0
    temp_df.loc[temp_df['wei_bi'] == '-', 'wei_bi'] = 0
    temp_df.loc[temp_df['yesterday_price'] == '-', 'yesterday_price'] = 0
    temp_df.loc[temp_df['now_price'] == '-', 'now_price'] = 0
    temp_df.loc[temp_df['chg'] == '-', 'chg'] = 0
    temp_df.loc[temp_df['volume'] == '-', 'volume'] = 0
    temp_df.loc[temp_df['amount'] == '-', 'amount'] = 0
    temp_df.loc[temp_df['exchange'] == '-', 'exchange'] = 0
    temp_df.loc[temp_df['quantity_ratio'] == '-', 'quantity_ratio'] = 0
    temp_df.loc[temp_df['high'] == '-', 'high'] = 0
    temp_df.loc[temp_df['low'] == '-', 'low'] = 0
    temp_df.loc[temp_df['open'] == '-', 'open'] = 0
    temp_df.loc[temp_df['total_mv'] == '-', 'total_mv'] = 0
    temp_df.loc[temp_df['flow_mv'] == '-', 'flow_mv'] = 0
    temp_df.loc[temp_df['inner_disk'] == '-', 'inner_disk'] = 0
    temp_df.loc[temp_df['outer_disk'] == '-', 'outer_disk'] = 0
    temp_df.loc[temp_df['today_main_net_inflow_ratio'] == '-', 'today_main_net_inflow_ratio'] = 0
    temp_df.loc[temp_df['today_main_net_inflow'] == '-', 'today_main_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow'] == '-', 'super_large_order_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow_ratio'] == '-', 'super_large_order_net_inflow_ratio'] = 0
    temp_df.loc[temp_df['large_order_net_inflow'] == '-', 'large_order_net_inflow'] = 0
    # temp_df.loc[temp_df['medium_order_net_inflow'] == '-', 'medium_order_net_inflow'] = 0
    # temp_df.loc[temp_df['small_order_net_inflow'] == '-', 'small_order_net_inflow'] = 0

    temp_df["list_date"] = pd.to_numeric(temp_df["list_date"], errors="coerce")
    temp_df["wei_bi"] = pd.to_numeric(temp_df["wei_bi"], errors="coerce")
    temp_df["average_price"] = pd.to_numeric(temp_df["average_price"], errors="coerce")
    temp_df["yesterday_price"] = pd.to_numeric(temp_df["yesterday_price"], errors="coerce")
    temp_df["now_price"] = pd.to_numeric(temp_df["now_price"], errors="coerce")
    temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
    temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
    temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
    temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
    temp_df["quantity_ratio"] = pd.to_numeric(temp_df["quantity_ratio"], errors="coerce")
    temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
    temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
    temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
    temp_df["total_mv"] = pd.to_numeric(temp_df["total_mv"], errors="coerce")
    temp_df["flow_mv"] = pd.to_numeric(temp_df["flow_mv"], errors="coerce")
    temp_df["outer_disk"] = pd.to_numeric(temp_df["outer_disk"], errors="coerce")
    temp_df["inner_disk"] = pd.to_numeric(temp_df["inner_disk"], errors="coerce")
    temp_df["today_main_net_inflow"] = pd.to_numeric(temp_df["today_main_net_inflow"], errors="coerce")
    temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"],
                                                            errors="coerce")
    temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                  errors="coerce")
    temp_df["large_order_net_inflow"] = pd.to_numeric(temp_df["large_order_net_inflow"],
                                                      errors="coerce")
    # temp_df["medium_order_net_inflow"] = pd.to_numeric(temp_df["medium_order_net_inflow"],
    #                                                    errors="coerce")
    # temp_df["small_order_net_inflow"] = pd.to_numeric(temp_df["small_order_net_inflow"], errors="coerce")

    # 大单比例
    temp_df['large_order_net_inflow_ratio'] = round((temp_df['large_order_net_inflow'] / temp_df['amount']) * 100, 2)

    # 外盘是内盘倍数
    temp_df['disk_ratio'] = round((temp_df['outer_disk'] - temp_df['inner_disk']) / temp_df['inner_disk'], 2)
    # 只有外盘没有内盘
    temp_df.loc[temp_df["inner_disk"] == 0, ['disk_ratio']] = 1688

    return temp_df


# 示例调用
if __name__ == "__main__":
    while True:
        df = get_real_time_quotes_all_stocks()
        print(df)
        zt_df = df.loc[df['wei_bi'] == 100]
        logger.info("涨停数据,{}", zt_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import akshare as ak
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.utils.date_handle_util as date_handle_util


def stock_em_dt_pool_df(date):
    try:
        date = date_handle_util.no_slash_date(date)
        stock_dt_pool_df = ak.stock_zt_pool_dtgc_em(date)
        if data_frame_util.is_empty(stock_dt_pool_df):
            return None
        stock_dt_pool_df.rename(columns={"序号": "index",
                                         "代码": "symbol",
                                         "名称": "name",
                                         "涨跌幅": "chg",
                                         "最新价": "now_price",
                                         "成交额": "amount",
                                         "流通市值": "flow_mv",
                                         "总市值": "total_mv",
                                         "动态市盈率": "ttm_pe",
                                         "换手率": "exchange",
                                         "封单资金": "closure_funds",
                                         "最后封板时间": "last_closure_time",
                                         "板上成交额": "plates_deal",
                                         "连续跌停": "connected_boards_numbers",
                                         "开板次数": "frying_plates_numbers",
                                         "所属行业": "industry"
                                         }, inplace=True)
        stock_dt_pool_df.loc[stock_dt_pool_df['amount'] == '-', 'amount'] = 0
        stock_dt_pool_df.loc[stock_dt_pool_df['exchange'] == '-', 'exchange'] = 0
        stock_dt_pool_df.loc[stock_dt_pool_df['closure_funds'] == '-', 'closure_funds'] = 0
        return stock_dt_pool_df
    except BaseException as e:
        logger.error("同步股票跌停数据出现异常:{},{}", date, e)
        return None


if __name__ == '__main__':
    stock_em_dt_pool_df('20231215')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

from concurrent.futures import ThreadPoolExecutor
import pandas as pd
from loguru import logger
import requests
import time
import numpy as np

# 最大返回条数
max_number = 1200
# 最小返回条数
min_number = 1000
# 分页条数
page_number = 200


def get_fund_etf_page_df(pn) -> pd.DataFrame:
    """
    东方财富-ETF 实时行情
    https://quote.eastmoney.com/center/gridlist.html#fund_etf
    :return: ETF 实时行情
    :rtype: pandas.DataFrame
    """
    current_timestamp = str(int(round(time.time() * 1000, 0)))
    url = "https://88.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "pn": str(pn),
        "pz": "5000",
        "po": "1",
        "np": "3",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f3",
        "fs": "b:MK0021,b:MK0022,b:MK0023,b:MK0024",
        "fields": (
            "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,"
            "f12,f13,f14,f15,f16,f17,f18,f20,f21,"
            "f23,f24,f25,f26,f22,f11,f30,f31,f32,f33,"
            "f34,f35,f38,f62,f63,f64,f65,f66,f69,"
            "f72,f75,f78,f81,f84,f87,f115,f124,f128,"
            "f136,f152,f184,f297,f402,f441"
        ),
        "_": str(current_timestamp),
    }
    try:
        r = requests.get(url, timeout=15, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["diff"])
        temp_df.rename(
            columns={
                "f26": "上市时间",
                "f12": "代码",
                "f14": "名称",
                "f2": "最新价",
                "f4": "涨跌额",
                "f3": "涨跌幅",
                "f5": "成交量",
                "f6": "成交额",
                "f7": "振幅",
                "f17": "开盘价",
                "f15": "最高价",
                "f16": "最低价",
                "f18": "昨收",
                "f8": "换手率",
                "f10": "量比",
                "f30": "现手",
                "f31": "买一",
                "f32": "卖一",
                "f33": "委比",
                "f34": "外盘",
                "f35": "内盘",
                "f62": "主力净流入-净额",
                "f184": "主力净流入-净占比",
                "f66": "超大单净流入-净额",
                "f69": "超大单净流入-净占比",
                "f72": "大单净流入-净额",
                "f75": "大单净流入-净占比",
                "f78": "中单净流入-净额",
                "f81": "中单净流入-净占比",
                "f84": "小单净流入-净额",
                "f87": "小单净流入-净占比",
                "f38": "最新份额",
                "f21": "流通市值",
                "f20": "总市值",
                "f402": "基金折价率",
                "f441": "IOPV实时估值",
                "f297": "数据日期",
                "f124": "更新时间",
                "f13": "market"
            },
            inplace=True,
        )
        temp_df = temp_df[
            [
                "代码",
                "名称",
                "最新价",
                "IOPV实时估值",
                "基金折价率",
                "涨跌额",
                "涨跌幅",
                "成交量",
                "成交额",
                "开盘价",
                "最高价",
                "最低价",
                "昨收",
                "振幅",
                "换手率",
                "量比",
                "委比",
                "外盘",
                "内盘",
                "主力净流入-净额",
                "主力净流入-净占比",
                "超大单净流入-净额",
                "超大单净流入-净占比",
                "大单净流入-净额",
                "大单净流入-净占比",
                "中单净流入-净额",
                "中单净流入-净占比",
                "小单净流入-净额",
                "小单净流入-净占比",
                "现手",
                "买一",
                "卖一",
                "最新份额",
                "流通市值",
                "总市值",
                "数据日期",
                "更新时间",
                "market",
                "上市时间"
            ]
        ]
        temp_df["最新价"] = pd.to_numeric(temp_df["最新价"], errors="coerce")
        temp_df["涨跌额"] = pd.to_numeric(temp_df["涨跌额"], errors="coerce")
        temp_df["涨跌幅"] = pd.to_numeric(temp_df["涨跌幅"], errors="coerce")
        temp_df["成交量"] = pd.to_numeric(temp_df["成交量"], errors="coerce")
        temp_df["成交额"] = pd.to_numeric(temp_df["成交额"], errors="coerce")
        temp_df["开盘价"] = pd.to_numeric(temp_df["开盘价"], errors="coerce")
        temp_df["最高价"] = pd.to_numeric(temp_df["最高价"], errors="coerce")
        temp_df["最低价"] = pd.to_numeric(temp_df["最低价"], errors="coerce")
        temp_df["昨收"] = pd.to_numeric(temp_df["昨收"], errors="coerce")
        temp_df["换手率"] = pd.to_numeric(temp_df["换手率"], errors="coerce")
        temp_df["量比"] = pd.to_numeric(temp_df["量比"], errors="coerce")
        temp_df["委比"] = pd.to_numeric(temp_df["委比"], errors="coerce")
        temp_df["外盘"] = pd.to_numeric(temp_df["外盘"], errors="coerce")
        temp_df["内盘"] = pd.to_numeric(temp_df["内盘"], errors="coerce")
        temp_df["流通市值"] = pd.to_numeric(temp_df["流通市值"], errors="coerce")
        temp_df["总市值"] = pd.to_numeric(temp_df["总市值"], errors="coerce")
        temp_df["振幅"] = pd.to_numeric(temp_df["振幅"], errors="coerce")
        temp_df["现手"] = pd.to_numeric(temp_df["现手"], errors="coerce")
        temp_df["买一"] = pd.to_numeric(temp_df["买一"], errors="coerce")
        temp_df["卖一"] = pd.to_numeric(temp_df["卖一"], errors="coerce")
        temp_df["最新份额"] = pd.to_numeric(temp_df["最新份额"], errors="coerce")
        temp_df["IOPV实时估值"] = pd.to_numeric(temp_df["IOPV实时估值"], errors="coerce")
        temp_df["基金折价率"] = pd.to_numeric(temp_df["基金折价率"], errors="coerce")
        temp_df["主力净流入-净额"] = pd.to_numeric(
            temp_df["主力净流入-净额"], errors="coerce"
        )
        temp_df["主力净流入-净占比"] = pd.to_numeric(
            temp_df["主力净流入-净占比"], errors="coerce"
        )
        temp_df["超大单净流入-净额"] = pd.to_numeric(
            temp_df["超大单净流入-净额"], errors="coerce"
        )
        temp_df["超大单净流入-净占比"] = pd.to_numeric(
            temp_df["超大单净流入-净占比"], errors="coerce"
        )
        temp_df["大单净流入-净额"] = pd.to_numeric(
            temp_df["大单净流入-净额"], errors="coerce"
        )
        temp_df["大单净流入-净占比"] = pd.to_numeric(
            temp_df["大单净流入-净占比"], errors="coerce"
        )
        temp_df["中单净流入-净额"] = pd.to_numeric(
            temp_df["中单净流入-净额"], errors="coerce"
        )
        temp_df["中单净流入-净占比"] = pd.to_numeric(
            temp_df["中单净流入-净占比"], errors="coerce"
        )
        temp_df["小单净流入-净额"] = pd.to_numeric(
            temp_df["小单净流入-净额"], errors="coerce"
        )
        temp_df["小单净流入-净占比"] = pd.to_numeric(
            temp_df["小单净流入-净占比"], errors="coerce"
        )
        temp_df["数据日期"] = pd.to_datetime(
            temp_df["数据日期"], format="%Y%m%d", errors="coerce"
        )
        temp_df["更新时间"] = (
            pd.to_datetime(temp_df["更新时间"], unit="s", errors="coerce")
            .dt.tz_localize("UTC")
            .dt.tz_convert("Asia/Shanghai")
        )

        return temp_df
    except Exception as e:
        logger.error("获取ETF列表,实时行情异常:{}", e)
        return pd.DataFrame()


def thread_pool_executor():
    """
       使用多线程获取所有ETF数据
       """
    # 计算总页数，假设总共有1000条数据，每页200条

    per_page = page_number
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整

    # 创建线程池
    with ThreadPoolExecutor(max_workers=3) as executor:
        # 提交任务，获取每页数据
        futures = [executor.submit(get_fund_etf_page_df, pn)
                   for pn in range(1, total_pages + 1)]

        # 收集结果
        results = []
        for future in futures:
            result = future.result()
            if not result.empty:
                results.append(result)

    # 合并所有页面的数据
    if results:
        return pd.concat(results, ignore_index=True)
    else:
        return pd.DataFrame()


def rename_etf(fund_etf_spot_em_df):
    fund_etf_spot_em_df = fund_etf_spot_em_df.rename(columns={
        "上市时间": "list_date",
        "最新价": "now_price",
        "涨跌幅": "chg",
        "基金折价率": "fund_discount_rate",
        "振幅": "pct_chg",
        "涨跌额": "range",
        "成交额": "amount",
        "成交量": "volume",
        "换手率": "exchange",
        "量比": "quantity_ratio",
        "代码": "symbol",
        "名称": "name",
        "最高价": "high",
        "最低价": "low",
        "开盘价": "open",
        "昨收": "yesterday_price",
        "总市值": "total_mv",
        "流通市值": "flow_mv",
        "委比": "wei_bi",
        "外盘": "outer_disk",
        "内盘": "inner_disk",
        "主力净流入-净额": "today_main_net_inflow",
        "超大单净流入-净额": "super_large_order_net_inflow",
        "超大单净流入-净占比": "super_large_order_net_inflow_ratio",
        "大单净流入-净额": "large_order_net_inflow",
        # "f78": "medium_order_net_inflow",
        # "f84": "small_order_net_inflow",
        # "f103": "concept",
        "主力净流入-净占比": "today_main_net_inflow_ratio",
        "买一": "buy_1_num",
        "卖一": "sell_1_num",
        "最新份额": "latest_share",
        "数据日期": "data_time",
        "更新时间": "update_time"
    })

    fund_etf_spot_em_df = fund_etf_spot_em_df[[
        "now_price",
        "chg",
        "fund_discount_rate",
        "pct_chg",
        "range",
        "amount",
        "volume",
        "exchange",
        "quantity_ratio",
        "symbol",
        "name",
        "high",
        "low",
        "open",
        "yesterday_price",
        "total_mv",
        "flow_mv",
        "wei_bi",
        "outer_disk",
        "inner_disk",
        "today_main_net_inflow",
        "super_large_order_net_inflow",
        "super_large_order_net_inflow_ratio",
        "large_order_net_inflow",
        "today_main_net_inflow_ratio",
        "buy_1_num",
        "sell_1_num",
        "latest_share",
        "data_time",
        "update_time",
        "market",
        'list_date'
    ]]

    fund_etf_spot_em_df['disk_ratio'] = round(
        (fund_etf_spot_em_df['outer_disk'] - fund_etf_spot_em_df['inner_disk']) / fund_etf_spot_em_df['inner_disk'], 2)

    fund_etf_spot_em_df.loc[:, 'reference_main_inflow'] = round(
        (fund_etf_spot_em_df['flow_mv'] * (1 / 1000)), 2)

    fund_etf_spot_em_df.loc[:, 'main_inflow_multiple'] = round(
        (fund_etf_spot_em_df['today_main_net_inflow'] / fund_etf_spot_em_df['reference_main_inflow']), 2)

    fund_etf_spot_em_df.loc[:, 'super_main_inflow_multiple'] = round(
        (fund_etf_spot_em_df['super_large_order_net_inflow'] / fund_etf_spot_em_df['reference_main_inflow']), 2)
    fund_etf_spot_em_df['large_inflow_multiple'] = round(
        (fund_etf_spot_em_df['large_order_net_inflow'] / fund_etf_spot_em_df['reference_main_inflow']), 2)

    fund_etf_spot_em_df['disk_diff_amount'] = round(
        (fund_etf_spot_em_df['outer_disk'] - fund_etf_spot_em_df['inner_disk']) * fund_etf_spot_em_df[
            "now_price"] * 100,
        2)

    fund_etf_spot_em_df['disk_diff_amount_exchange'] = round(
        (fund_etf_spot_em_df['disk_diff_amount'] / fund_etf_spot_em_df['reference_main_inflow']), 2)
    fund_etf_spot_em_df.loc[:, 'sum_main_inflow_disk'] = fund_etf_spot_em_df['main_inflow_multiple'] + \
                                                         fund_etf_spot_em_df['disk_diff_amount_exchange']
    fund_etf_spot_em_df = fund_etf_spot_em_df.fillna(0)

    fund_etf_spot_em_df.replace([np.inf, -np.inf], 0, inplace=True)
    return fund_etf_spot_em_df


def get_etf_real_time_quotes():
    # 获取第一页数据
    page_one_df = get_fund_etf_page_df(1)
    # 数据接口正常返回5600以上的数量
    if page_one_df.shape[0] > min_number:
        page_one_df = rename_etf(page_one_df)
        return page_one_df
    else:
        page_df = thread_pool_executor()
        page_df = rename_etf(page_df)
        return page_df


if __name__ == '__main__':
    fund_etf_df = get_etf_real_time_quotes()
    fund_etf_df = fund_etf_df.sort_values(by=['amount'], ascending=False)
    fund_etf_df = fund_etf_df.fillna(0)
    print(fund_etf_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

from loguru import logger
import time
import requests

import mns_common.utils.data_frame_util as data_frame_util
from io import StringIO
import pandas as pd
from bs4 import BeautifulSoup
from akshare.utils.tqdm import get_tqdm
import mns_common.component.cookie.cookie_info_service as cookie_info_service

'''
获取单只股票代码 symbol 所有概念详情
'''
# 获取单个股票新增概念
# https://basic.10jqka.com.cn/basicph/briefinfo.html#/concept?broker=anelicaiapp&showtab=1&code=301016&code_name=%E9%9B%B7%E5%B0%94%E4%BC%9F&market_id=33
'''

'''


def get_one_symbol_all_ths_concepts(symbol: str = "305794") -> pd.DataFrame:
    try:
        url = f"http://basic.10jqka.com.cn/api/stockph/conceptdetail/{symbol}"
        headers = {
            "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 15_4_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 iOS AYLCAPP/9.1.2.0/h4526a24eb9445522492fd64caae11b1f scheme/anelicaiapp deviceinfo/I|9.1.2.0|NA|h4526a24eb9445522492fd64caae11b1f pastheme/0",
            "Cookie": "ps_login_app_name=AYLCAPP;"
                      "ps_login_token_id=N_C993F777ACC500B354C762A2627A8862348FC8163799A08EBEB2301C28A2135D220475787D0E81425C1134E15D8CC8761D639FEDBD46C00FE8EA6482C1E42D9801B19918FB3F5C34;"
                      "ps_login_union_id=edc29089a2b64e3882062297030a0386;PAS.CURRENTUNIONID=edc29089a2b64e3882062297030a0386"
        }
        r = requests.get(url, headers=headers)
        data_json = r.json()
        data_concept = data_json['data']
        errorcode = data_json['errorcode']
        errormsg = data_json['errormsg']
        if errorcode == '0' and errormsg == '':
            data_concept_df = pd.DataFrame(data_concept)
            return data_concept_df
        else:
            return None
    except BaseException as e:
        logger.error("获取symbol概念信息异常:{},{}", symbol, e)


# web端口 获取概念详情 极容易被封 最好不使用了
def stock_board_cons_ths(symbol: str = "301558") -> pd.DataFrame:
    """
    通过输入行业板块或者概念板块的代码获取成份股
    https://q.10jqka.com.cn/thshy/detail/code/881121/
    https://q.10jqka.com.cn/gn/detail/code/301558/
    :param symbol: 行业板块或者概念板块的代码
    :type symbol: str
    :return: 行业板块或者概念板块的成份股
    :rtype: pandas.DataFrame
    """
    ths_cookie = cookie_info_service.get_ths_cookie()

    headers = {
        "Accept": "text/html, */*; q=0.01",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Connection": "keep-alive",
        "Referer": "https://q.10jqka.com.cn/thshy/detail/code/881160/",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
        "hexin-v": "A8KlBtusEcYFfQ2aigv4OairE8Mhk8SaeJa61gzb7ZTh7mx99CMWvUgnCuLf",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "sec-ch-ua-mobile": "?0",
        "sec-ch-ua-platform": "\"Windows\"",
        "cookie": ths_cookie
    }
    url = f"https://q.10jqka.com.cn/thshy/detail/field/199112/order/desc/page/1/ajax/1/code/{symbol}"
    r = requests.get(url, headers=headers)
    if r.status_code != 200:
        return None
    soup = BeautifulSoup(r.text, "lxml")
    url_flag = "thshy"
    if soup.find(name="td", attrs={"colspan": "14"}):
        new_url = f"https://q.10jqka.com.cn/gn/detail/field/199112/order/desc/page/1/ajax/1/code/{symbol}"
        r = requests.get(new_url, headers=headers)
        soup = BeautifulSoup(r.text, features="lxml")
        url_flag = "gn"
    try:
        page_num = int(
            soup.find_all(name="a", attrs={"class": "changePage"})[-1]["page"]
        )
    except IndexError:
        page_num = 1
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, page_num + 1), leave=False):
        try:
            time.sleep(2)
            new_url = f"https://q.10jqka.com.cn/{url_flag}/detail/field/199112/order/desc/page/{page}/ajax/1/code/{symbol}"
            r_detail = requests.get(new_url, headers=headers)
            if r_detail.status_code == 200:
                temp_df = pd.read_html(StringIO(r_detail.text))[0]
                big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
        except BaseException as e:
            logger.error("获取概念详细信息异常:{},{}", symbol, e)
    big_df.rename(
        {
            "涨跌幅(%)": "涨跌幅",
            "涨速(%)": "涨速",
            "换手(%)": "换手",
            "振幅(%)": "振幅",
        },
        inplace=True,
        axis=1,
    )
    if '加自选' in big_df.columns:
        del big_df["加自选"]
    if '代码' not in big_df.columns:
        return None
    big_df["代码"] = big_df["代码"].astype(str).str.zfill(6)
    if data_frame_util.is_not_empty(big_df):
        big_df.rename(columns={"序号": "index",
                               "代码": "symbol",
                               "名称": "name",
                               "现价": "now_price",
                               "涨跌幅": "chg",
                               "涨跌": "change",
                               "涨速": "r_increase",
                               "换手": "exchange",
                               "量比": "q_ratio",
                               "振幅": "pct_chg",
                               "成交额": "amount",
                               "流通股": "tradable_shares",
                               "流通市值": "flow_mv",
                               "市盈率": "pe"
                               }, inplace=True)
        stock_board_cons_ths_df = big_df[
            big_df["index"] != '暂无成份股数据']

        if stock_board_cons_ths_df is None or stock_board_cons_ths_df.shape[0] == 0:
            return
        length = len(list(stock_board_cons_ths_df))
        stock_board_cons_ths_df.insert(length, 'concept_code', symbol)

        stock_board_cons_ths_df['amount'] = stock_board_cons_ths_df['amount'].apply(
            lambda x: pd.to_numeric(x.replace('亿', ''), errors="coerce"))

        stock_board_cons_ths_df['tradable_shares'] = stock_board_cons_ths_df['tradable_shares'].apply(
            lambda x: pd.to_numeric(x.replace('亿', ''), errors="coerce"))

        stock_board_cons_ths_df['flow_mv'] = stock_board_cons_ths_df['flow_mv'].apply(
            lambda x: pd.to_numeric(x.replace('亿', ''), errors="coerce"))
    return stock_board_cons_ths_df


if __name__ == '__main__':
    concept_df = stock_board_cons_ths('886076')

    print(concept_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import requests
from bs4 import BeautifulSoup
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger


# 获取参股公司 子公司 孙公司 联营企业
def get_company_hold_info(symbol, ths_cookie):
    try:

        url = "https://basic.10jqka.com.cn/new/" + symbol + "/company.html"

        headers = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Cache-Control": "max-age=0",
            "Connection": "keep-alive",
            "Sec-Fetch-Dest": "document",
            "Sec-Fetch-Mode": "navigate",
            "Sec-Fetch-Site": "cross-site",
            "Sec-Fetch-User": "?1",
            "Upgrade-Insecure-Requests": "1",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36",
            "sec-ch-ua": "\"Google Chrome\";v=\"129\", \"Not=A?Brand\";v=\"8\", \"Chromium\";v=\"129\"",
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": "\"Windows\"",
            "cookie": ths_cookie
        }
        cookies = {
            "searchGuide": "sg",
            "skin_color": "white",
            "Hm_lvt_722143063e4892925903024537075d0d": "1725031809,1725842892,1726621825,1727227162",
            "Hm_lvt_929f8b362150b1f77b477230541dbbc2": "1725031809,1725842892,1726621825,1727227162",
            "spversion": "20130314",
            "user": "MDq%2BsNDQcE06Ok5vbmU6NTAwOjYxMzk4NTQ0ODo1LDEsMjA7NiwxLDIwOzcsMTExMTExMTExMTEwLDIwOzgsMTExMTAxMTEwMDAwMTExMTEwMDEwMDEwMDEwMDAwMDAsMjA7MzMsMDAwMTAwMDAwMDAwLDIwOzM2LDEwMDExMTExMDAwMDExMDAxMDExMTExMSwyMDs0NiwwMDAwMTExMTEwMDAwMDExMTExMTExMTEsMjA7NTEsMTEwMDAwMDAwMDAwMDAwMCwyMDs1OCwwMDAwMDAwMDAwMDAwMDAwMSwyMDs3OCwxLDIwOzg3LDAwMDAwMDAwMDAwMDAwMDAwMDAxMDAwMCwyMDsxMTksMDAwMDAwMDAwMDAwMDAwMDAwMTAxMDAwMDAsMjA7MTI1LDExLDIwOzQ0LDExLDQwOzEsMTAxLDQwOzIsMSw0MDszLDEsNDA7MTAyLDEsNDA6Mjc6Ojo2MDM5ODU0NDg6MTcyODQ4NzEyNjo6OjE2MzQ1NjY5ODA6NjA0ODAwOjA6MTRhZjIxYmRiNTgzODUxOTgxZWVjZGQ4NjQxZjA2NDg5OmRlZmF1bHRfNDox",
            "userid": "603985448",
            "u_name": "%BE%B0%D0%D0pM",
            "escapename": "%25u666f%25u884cpM",
            "ticket": "955f0ee44d86aede75787f64ae45bae9",
            "user_status": "0",
            "utk": "2df15e757efe7d4a489cf764fa371ff9",
            "Hm_lvt_78c58f01938e4d85eaf619eae71b4ed1": "1728463065,1728526291,1728541890,1728550124",
            "historystock": "301551%7C*%7C002205%7C*%7C000627%7C*%7C300746%7C*%7C300139",
            "reviewJump": "nojump",
            "usersurvey": "1",
            "v": "A8mumxxpynGwb7YF90Bxvvav2P4mFrxUJwzh32s-RzXtX-dgs2bNGLda8aj4"
        }
        response = requests.get(url, headers=headers, cookies=cookies)
        soup = BeautifulSoup(response.content, "lxml")

        # 找到表格
        table = soup.find('table', id='ckg_table')

        # 提取表头
        table_headers = [header.get_text(strip=True) for header in table.find_all('th')]

        # 提取表格数据
        data = []
        for row in table.find_all('tr')[1:]:  # 跳过表头
            cells = [cell.get_text(strip=True) for cell in row.find_all('td')]
            if cells:  # 确保行不为空
                data.append(cells)

        # 创建 DataFrame
        df = pd.DataFrame(data, columns=table_headers)
        if data_frame_util.is_empty(df):
            return pd.DataFrame()
        del df['序号']

        ['序号', '关联公司名称', '参控关系', '参控比例', '投资金额(元)', '被参控公司净利润(元)', '是否报表合并',
         '被参股公司主营业务']

        df = df.rename(columns={"关联公司名称": "holding_company",
                                "参控关系": "holding_relation",
                                "参控比例": "holding_percent_name",
                                "投资金额(元)": "invest_amount_name",
                                "被参控公司净利润(元)": "holding_net_profit_name",
                                "是否报表合并": "consolidation_report",
                                "被参股公司主营业务": "holding_main_business"
                                })
        df['holding_percent'] = df['holding_percent_name'].apply(convert_to_float)
        df['invest_amount'] = df['invest_amount_name'].apply(convert_to_float)
        df['holding_net_profit'] = df['holding_net_profit_name'].apply(convert_to_float)
        df['symbol'] = symbol

        return df
    except BaseException as e:
        logger.error("获取公司参股公司信息异常:{},{}", symbol, e)
        return pd.DataFrame()


# 数据清洗与转换
# 定义一个函数将带有单位的字符串转换为数字
def convert_to_float(value):
    if '亿' in value:
        return float(value.replace('亿', '').replace(' ', '').replace('元', '')) * 1e8
    elif '%' in value:
        return float(value.replace('%', '').replace(' ', '')) / 100
    elif '万' in value:
        return float(value.replace('万', '').replace(' ', '').replace('元', '')) * 1e4
    elif '未披露' in value:
        return 0
    return -1


# 获取公司热点
def get_company_hot_info(symbol, ths_cookie):
    try:

        url = "https://basic.10jqka.com.cn/new/" + symbol + "/"

        headers = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Cache-Control": "max-age=0",
            "Connection": "keep-alive",
            "Sec-Fetch-Dest": "document",
            "Sec-Fetch-Mode": "navigate",
            "Sec-Fetch-Site": "cross-site",
            "Sec-Fetch-User": "?1",
            "Upgrade-Insecure-Requests": "1",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36",
            "sec-ch-ua": "\"Google Chrome\";v=\"129\", \"Not=A?Brand\";v=\"8\", \"Chromium\";v=\"129\"",
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": "\"Windows\"",
            "cookie": ths_cookie
        }
        cookies = {
            "searchGuide": "sg",
            "skin_color": "white",
            "Hm_lvt_722143063e4892925903024537075d0d": "1725031809,1725842892,1726621825,1727227162",
            "Hm_lvt_929f8b362150b1f77b477230541dbbc2": "1725031809,1725842892,1726621825,1727227162",
            "spversion": "20130314",
            "user": "MDq%2BsNDQcE06Ok5vbmU6NTAwOjYxMzk4NTQ0ODo1LDEsMjA7NiwxLDIwOzcsMTExMTExMTExMTEwLDIwOzgsMTExMTAxMTEwMDAwMTExMTEwMDEwMDEwMDEwMDAwMDAsMjA7MzMsMDAwMTAwMDAwMDAwLDIwOzM2LDEwMDExMTExMDAwMDExMDAxMDExMTExMSwyMDs0NiwwMDAwMTExMTEwMDAwMDExMTExMTExMTEsMjA7NTEsMTEwMDAwMDAwMDAwMDAwMCwyMDs1OCwwMDAwMDAwMDAwMDAwMDAwMSwyMDs3OCwxLDIwOzg3LDAwMDAwMDAwMDAwMDAwMDAwMDAxMDAwMCwyMDsxMTksMDAwMDAwMDAwMDAwMDAwMDAwMTAxMDAwMDAsMjA7MTI1LDExLDIwOzQ0LDExLDQwOzEsMTAxLDQwOzIsMSw0MDszLDEsNDA7MTAyLDEsNDA6Mjc6Ojo2MDM5ODU0NDg6MTcyODQ4NzEyNjo6OjE2MzQ1NjY5ODA6NjA0ODAwOjA6MTRhZjIxYmRiNTgzODUxOTgxZWVjZGQ4NjQxZjA2NDg5OmRlZmF1bHRfNDox",
            "userid": "603985448",
            "u_name": "%BE%B0%D0%D0pM",
            "escapename": "%25u666f%25u884cpM",
            "ticket": "955f0ee44d86aede75787f64ae45bae9",
            "user_status": "0",
            "utk": "2df15e757efe7d4a489cf764fa371ff9",
            "Hm_lvt_78c58f01938e4d85eaf619eae71b4ed1": "1728463065,1728526291,1728541890,1728550124",
            "historystock": "301551%7C*%7C002205%7C*%7C000627%7C*%7C300746%7C*%7C300139",
            "reviewJump": "nojump",
            "usersurvey": "1",
            "v": "A8mumxxpynGwb7YF90Bxvvav2P4mFrxUJwzh32s-RzXtX-dgs2bNGLda8aj4"
        }
        response = requests.get(url, headers=headers, cookies=cookies)
        soup = BeautifulSoup(response.content, "html.parser")
        analysis_div = soup.find('div', class_='check_else')
        # 找到表格  <table class="m_table m_table_db" id="tableToday" style="margin-bottom: 10px;margin-top:0px">
        # 提取文本并去除空白字符
        if analysis_div:
            analysis_text = analysis_div.get_text(strip=True)
            return analysis_text
        else:
            return ''
    except BaseException as e:
        logger.error("获取公司参股公司信息异常:{},{}", symbol, e)
        return ''


from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
if __name__ == '__main__':
    stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "ths_cookie", })
    ths_cookie_test = list(stock_account_info['cookie'])[0]
    company_df_test = get_company_hot_info('000833', ths_cookie_test)
    print(company_df_test)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)


def rename_kpl_plate_detail(kpl_plate_detail_df):
    kpl_plate_detail_df = kpl_plate_detail_df.rename(columns={0: "symbol",
                                                              1: "name",
                                                              2: "you_zi",
                                                              4: "plate_name_list",
                                                              5: "now_price",
                                                              6: "chg",
                                                              7: "amount",
                                                              8: "real_exchange",
                                                              9: "speed",
                                                              10: "real_flow_mv",
                                                              11: "main_flow_in",
                                                              12: "main_flow_out",
                                                              13: "main_flow_net",
                                                              18: "sell_radio",

                                                              20: "chg_from_chg",

                                                              21: "quantity_ratio",
                                                              23: "connected_boards",
                                                              24: "dragon_index",
                                                              25: "exchange",
                                                              28: "closure_funds",
                                                              29: "max_closure_funds",
                                                              33: "pct_chg",
                                                              37: "total_mv",
                                                              38: "flow_mv",
                                                              39: "most_relative_name",
                                                              40: "leader_up_number",
                                                              42: "last_reason_organ_add",
                                                              62: "pe"
                                                              })
    kpl_plate_detail_df[["symbol",
                         "name",
                         "you_zi",
                         "plate_name_list",
                         "now_price",
                         "chg",
                         "amount",
                         "real_exchange",
                         "speed",
                         "real_flow_mv",
                         "main_flow_in",
                         "main_flow_out",
                         "main_flow_net",
                         "sell_radio",
                         "chg_from_chg",
                         "quantity_ratio",
                         "connected_boards",
                         "dragon_index",
                         "exchange",
                         "closure_funds",
                         "max_closure_funds",
                         "pct_chg",
                         "total_mv",
                         "flow_mv",
                         "most_relative_name",
                         "leader_up_number",
                         "last_reason_organ_add",
                         "pe"]]
    return kpl_plate_detail_df


# 指数名称改名
def rename_plate_index(plate_index_df):
    plate_index_df = plate_index_df.rename(columns={
        0: "plate_code",
        1: "plate_name",
        2: "heat_score",
        3: "chg",
        4: "speed",
        5: "amount",
        6: "main_net_inflow",
        7: "main_inflow_in",
        8: "main_inflow_out",
        9: "quantity_ratio",
        10: "flow_mv",
        12: "super_order_net",
        13: "total_mv",
        14: "last_reason_organ_add",
        15: "ava_pe_now",
        16: "ava_pe_next"
    })
    plate_index_df = plate_index_df[[
        "plate_code",
        "plate_name",
        "heat_score",
        "chg",
        "speed",
        "amount",
        "main_net_inflow",
        "main_inflow_in",
        "main_inflow_out",
        "quantity_ratio",
        "flow_mv",
        "super_order_net",
        "total_mv",
        "last_reason_organ_add",
        "ava_pe_now",
        "ava_pe_next"
    ]]
    return plate_index_df
